<?php
// wbb imports
require_once(WBB_DIR.'lib/acp/form/LatestPostsAndThreadsListAddForm.class.php');

/**
 * Shows the latest posts and threads list edit form.
 * 
 * @author 	Nerd Almighty
 * @copyright	2009 Bergwerk <http://bergwerk.forenberg.de>
 * @license	Creative Commons - Attribution-Noncommercial-Share Alike 3.0 Unported <http://creativecommons.org/licenses/by-nc-sa/3.0/>
 * @package	com.bergwerk.wbb.page.user.latestPostsAndThreads
 * @subpackage	acp.form
 * @category 	Burning Board
 */
class LatestPostsAndThreadsListEditForm extends LatestPostsAndThreadsListAddForm {
	// system
	// public $templateName = 'latestPostsAndThreadsListEdit';
	public $activeMenuItem = 'wbb.acp.menu.link.content.board.latestPostsAndThreadsList';
	
	/**
	 * list id
	 *
	 * @var integer
	 */
	public $listID = 0;
	
	/**
	 * @see Page::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		// get list id
		if (isset($_REQUEST['listID'])) $this->listID = intval($_REQUEST['listID']);
		
		// get list
		$this->list = new LatestPostsAndThreadsListEditor($this->listID);
		
		if (!$this->list->listID) throw new IllegalLinkException();
	}
	
	/**
	 * @see Page::readData()
	 */
	public function readData() {
		parent::readData();
		
		if (!count($_POST)) {
			// default active tab item
			
			// get values
			$this->title = $this->list->title;
			$this->isEnabled = $this->list->isEnabled;
			$this->isDefault = $this->list->isDefault;
			$this->includedBoards = (strlen($this->list->includedBoards) ? explode(',', $this->list->includedBoards) : array());
			$this->includeAllBoards = $this->list->includeAllBoards;
			$this->excludedBoards = (strlen($this->list->excludedBoards) ? explode(',', $this->list->excludedBoards) : array());
			$this->parentBoards = (strlen($this->list->parentBoards) ? explode(',', $this->list->parentBoards) : array());
			$this->length = $this->list->length;
			$this->design = $this->list->design;
			$this->showStatusDisplayIcons = $this->list->showStatusDisplayIcons;
			$this->showColumnRating = $this->list->showColumnRating;
			$this->showColumnReplies = $this->list->showColumnReplies;
			$this->showColumnViews = $this->list->showColumnViews;
			$this->showLastPostTimeIcon = $this->list->showLastPostTimeIcon;
			$this->daysPrune = $this->list->daysPrune;
			$this->styleID = $this->list->styleID;
			$this->enforceStyle = $this->list->enforceStyle;
		}
	}
	
	/**
	 * @see Form::save()
	 */
	public function save() {
		AbstractForm::save();
		
		// implode selected boards
		$includedBoards = (count($this->includedBoards) ? implode(',', $this->includedBoards) : '');
		$excludedBoards = (count($this->excludedBoards) ? implode(',', $this->excludedBoards) : '');
		$parentBoards = (count($this->parentBoards) ? implode(',', $this->parentBoards) : '');
		
		// save list
		$fields = array(
			'title' => $this->title,
			'isEnabled' => $this->isEnabled,
			'isDefault' => $this->isDefault,
			'includedBoards' => $includedBoards,
			'includeAllBoards' => $this->includeAllBoards,
			'excludedBoards' => $excludedBoards,
			'parentBoards' => $parentBoards,
			'length' => $this->length,
			'design' => $this->design,
			'showStatusDisplayIcons' => $this->showStatusDisplayIcons,
			'showColumnRating' => $this->showColumnRating,
			'showColumnReplies' => $this->showColumnReplies,
			'showColumnViews' => $this->showColumnViews,
			'showLastPostTimeIcon' => $this->showLastPostTimeIcon,
			'daysPrune' => $this->daysPrune,
			'styleID' => $this->styleID,
			'enforceStyle' => $this->enforceStyle
		);
		
		$this->list->update($fields);

		$this->saved();
		
		// show success message
		WCF::getTPL()->assign(array(
			'list' => $this->list,
			'success' => true
		));
	}
	
	/**
	 * @see Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'action' => 'edit',
			'listID' => $this->listID,
			'list' => $this->list
		));
	}
}
?>