<?php
// wcf imports
require_once(WCF_DIR.'lib/page/SortablePage.class.php');

// wbb imports
require_once(WBB_DIR.'lib/data/thread/LatestPostsAndThreadsList.class.php');

/**
 * Shows a list of all latest posts and threads lists.
 * 
 * @author 	Nerd Almighty
 * @copyright	2009 Bergwerk <http://bergwerk.forenberg.de>
 * @license	Creative Commons - Attribution-Noncommercial-Share Alike 3.0 Unported <http://creativecommons.org/licenses/by-nc-sa/3.0/>
 * @package	com.bergwerk.wbb.page.user.latestPostsAndThreads
 * @subpackage	acp.page
 * @category 	Burning Board
 */
class LatestPostsAndThreadsListListPage extends SortablePage {
	// system
	public $templateName = 'latestPostsAndThreadsListList';
	public $activeMenuItem = 'wbb.acp.menu.link.content.board.latestPostsAndThreadsList.view';
	public $neededPermissions = 'admin.board.canEditLatestPostsAndThreadsList';
	public $defaultSortField = 'listID';
	
	/**
	 * list of latest posts and threads lists
	 * 
	 * @var array<LatestPostsAndThreadsList>
	 */
	public $lists = array();
	
	/**
	 * count of enabled lists
	 *
	 * @var integer
	 */
	public $enabledLists = 0;
	
	/**
	 * id of the last edited list
	 *
	 * @var integer
	 */
	public $listID = 0;
	
	/**
	 * @see Page::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		// handle list actions
		$listID = 0;
		$validActions = array('delete', 'enable', 'disable', 'setAsDefault', 'unsetDefault');
		if (isset($_REQUEST['listID'])) $listID = intval($_REQUEST['listID']);
		
		if ($listID && !empty($this->action)) {
			// get list editor
			require_once(WBB_DIR.'lib/data/thread/LatestPostsAndThreadsListEditor.class.php');
			$list = new LatestPostsAndThreadsListEditor($listID);
			if ($list->listID && in_array($this->action, $validActions)) {
				// check permissions
				WCF::getUser()->checkPermission($this->neededPermissions);
				
				if ($this->action == 'setAsDefault' || $this->action == 'unsetDefault') {
					LatestPostsAndThreadsListEditor::setDefaultList(($this->action == 'setAsDefault' ? $listID : 0));
					LatestPostsAndThreadsList::resetCache();
				}
				elseif ($this->action == 'enable' || $this->action == 'disable') {
					$list->update(array('isEnabled' => ($this->action == 'enable' ? 1 : 0)));
				}
				elseif ($this->action == 'delete') {
					$list->delete();
				}
				
				$this->listID = $list->listID;
			}
			else {
				// list doesn't exist, or action isn't a valid action
				throw new IllegalLinkException();
			}
		}
	}
	
	/**
	 * @see SortablePage::validateSortField()
	 */
	public function validateSortField() {
		parent::validateSortField();
		
		switch ($this->sortField) {
			case 'listID':
			case 'title':
			case 'isEnabled':
				break;
			default: $this->sortField = $this->defaultSortField;
		}
	}
	
	/**
	 * @see Page::readData()
	 */
	public function readData() {
		parent::readData();
		
		// reset data
		$this->lists = array();
		$this->enabledLists = 0;
		
		// read lists from database
		$sql = "SELECT		*
			FROM		wbb".WBB_N."_latest_posts_and_threads_list
			ORDER BY	isDefault DESC, ".$this->sortField." ".$this->sortOrder;
		$result = WCF::getDB()->sendQuery($sql);
		while ($row = WCF::getDB()->fetchArray($result)) {
			$this->lists[$row['listID']] = new LatestPostsAndThreadsList(null, $row);
			if ($row['isEnabled']) $this->enabledLists++;
		}
	}
	
	/**
	 * @see Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'lists' => $this->lists,
			'enabledLists' => $this->enabledLists,
			'listID' => $this->listID,
			'action' => $this->action
		));
	}
	
	/**
	 * @see Page::show()
	 */
	public function show() {
		// enable menu item
		WCFACP::getMenu()->setActiveMenuItem($this->activeMenuItem);
		
		// check permission
		WCF::getUser()->checkPermission($this->neededPermissions);
		
		parent::show();
	}
}
?>