<?php
// wbb imports
require_once(WBB_DIR.'lib/data/thread/LatestPostsAndThreadsList.class.php');

/**
 * Provides functions to edit the data of a LatestPostsAndThreadsList.
 *
 * @author 	Nerd Almighty
 * @copyright	2009 Bergwerk <http://bergwerk.forenberg.de>
 * @license	Creative Commons - Attribution-Noncommercial-Share Alike 3.0 Unported <http://creativecommons.org/licenses/by-nc-sa/3.0/>
 * @package	com.bergwerk.wbb.page.user.latestPostsAndThreads
 * @subpackage	data.thread
 * @category 	Burning Board
 */
class LatestPostsAndThreadsListEditor extends LatestPostsAndThreadsList {
	/**
	 * Holds all default values for a new list.
	 */
	public static $defaults = array(
		'isEnabled' => 1,
		'isDefault' => 0,
		'includedBoards' => '',
		'includeAllBoards' => 0,
		'excludedBoards' => '',
		'parentBoards' => '',
		'length' => 0,
		'design' => 0,
		'showStatusDisplayIcons' => -1,
		'showColumnRating' => -1,
		'showColumnReplies' => -1,
		'showColumnViews' => -1,
		'showLastPostTimeIcon' => -1,
		'daysPrune' => 0,
		'styleID' => 0,
		'enforceStyle' => 0
	);
	
	/**
	 * Creates a new latest posts and threads list.
	 * 
	 * @param	string		$title			name of the new list
	 * @param	array		$fields			additional list data
	 * @return	BoardEditor
	 */
	public static function create($title, $fields = array()) {
		// assign default values, if necessary
		foreach (self::$defaults as $key => $value) {
			if (!isset($fields[$key])) $fields[$key] = $value;
		}
		$fields['title'] = $title;
		
		// save data to database
		$listID = self::insert($fields);
		
		// set new default list, if necessary
		if ($fields['isDefault']) {
			self::setDefaultList($listID);
		}
		
		// reset cache
		self::resetCache();
		
		// return new list
		return new LatestPostsAndThreadsListEditor($listID);
	}
	
	/**
	 * Updates this list.
	 *
	 * @param	array		$fields			list data
	 */
	public function update($fields = array()) {
		// update data in database
		$this->updateData($this->listID, $fields);
		
		// set new default list, if necessary
		if (!$this->isDefault && isset($fields['isDefault']) && $fields['isDefault']) {
			self::setDefaultList($this->listID);
		}
		
		// reset cache
		self::resetCache();
	}
	
	/**
	 * Deletes this list.
	 *
	 */
	public function delete() {
		// delete list data from database
		self::deleteData($this->listID);
		
		// reset cache
		self::resetCache();
	}
	
	/**
	 * Creates the latest posts and threads list row in database table.
	 *
	 * @param 	array		$fields		list data
	 * @return	integer		new list id
	 */
	public static function insert($fields = array()) { 
		$keys = $values = $seperator = '';
		foreach ($fields as $key => $value) {
			$keys .= $seperator.$key;
			if (is_int($value)) $values .= $seperator.$value;
			else $values .= $seperator."'".escapeString($value)."'";
			$seperator = ",";
		}
		
		$sql = "INSERT INTO	wbb".WBB_N."_latest_posts_and_threads_list
					(".$keys.")
			VALUES		(".$values.")";
		WCF::getDB()->sendQuery($sql);
		return WCF::getDB()->getInsertID();
	}
	
	/**
	 * Updates the data of a latest posts and threads list.
	 *
	 * @param	mixed		list id (single id as integer, or multiple ids as array<integer>)
	 * @param	array		$fields		new list data
	 */
	public static function updateData($listIDs, $fields = array()) {
		if (is_array($listIDs)) $listIDs = implode(',', $listIDs);
		
		$updates = $seperator = '';
		foreach ($fields as $key => $value) {
			$updates .= $seperator.$key."=";
			if (is_int($value)) $updates .= $value;
			else $updates .= "'".escapeString($value)."'";
			$seperator = ",";
		}
		
		if (!empty($updates)) {
			$sql = "UPDATE	wbb".WBB_N."_latest_posts_and_threads_list
				SET	".$updates."
				WHERE	listID IN (".$listIDs.")";
			WCF::getDB()->sendQuery($sql);
		}
	}
	
	/**
	 * Deletes the data of a latest posts and threads list.
	 *
	 * @param	integer		list id (single id as integer, or multiple ids as array<integer>)
	 */
	public static function deleteData($listIDs) {
		if (is_array($listIDs)) $listIDs = implode(',', $listIDs);
		
		$sql = "DELETE FROM	wbb".WBB_N."_latest_posts_and_threads_list
			WHERE		listID IN (".$listIDs.")";
		WCF::getDB()->sendQuery($sql);
	}
	
	/**
	 * Sets a new list as default list.
	 *
	 * @param 	integer		id of the new default list, if 0, no new default list will be set
	 */
	public static function setDefaultList($listID = 0) { 
		// reset lists
		$sql = "UPDATE	wbb".WBB_N."_latest_posts_and_threads_list
			SET	isDefault = 0";
		WCF::getDB()->sendQuery($sql);
		
		// set new default list
		if ($listID) {
			$sql = "UPDATE	wbb".WBB_N."_latest_posts_and_threads_list
				SET	isDefault = 1, isEnabled = 1
				WHERE	listID = ".$listID;
			WCF::getDB()->sendQuery($sql);
		}
	}
} 
?>